package CPAN::Changes::CwaliteeCommon;

our $DATE = '2019-07-26'; # DATE
our $VERSION = '0.007'; # VERSION

1;
# ABSTRACT: Common routines/data for CPAN::Changes::Cwalitee

__END__

=pod

=encoding UTF-8

=head1 NAME

CPAN::Changes::CwaliteeCommon - Common routines/data for CPAN::Changes::Cwalitee

=head1 VERSION

This document describes version 0.007 of CPAN::Changes::CwaliteeCommon (from Perl distribution CPAN-Changes-Cwalitee), released on 2019-07-26.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/CPAN-Changes-Cwalitee>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-CPAN-Changes-Cwalitee>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=CPAN-Changes-Cwalitee>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
